pub struct Candidate { /* private fields */ }Expand description
Candidate used by the data-quality hygiene workflow; it finds duplicate, stale, or inconsistent records while blocking automatic provider-system mutation.
Implementations
Sourceimpl Candidate
impl Candidate
Sourcepub fn builder() -> CandidateBuilder
pub fn builder() -> CandidateBuilder
Create an instance of Candidate using the builder syntax
Sourceimpl Candidate
impl Candidate
Sourcepub const fn id(&self) -> &IssueRef
pub const fn id(&self) -> &IssueRef
Returns the id evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn kind(&self) -> CandidateKind
pub const fn kind(&self) -> CandidateKind
Returns the kind evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn issue(&self) -> &Issue
pub const fn issue(&self) -> &Issue
Returns the issue evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub fn source_record_refs(&self) -> &[RecordRef]
pub fn source_record_refs(&self) -> &[RecordRef]
Returns the source record refs evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn source_freshness(&self) -> SourceFreshness
pub const fn source_freshness(&self) -> SourceFreshness
Returns the source freshness evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn sensitivity(&self) -> Sensitivity
pub const fn sensitivity(&self) -> Sensitivity
Returns the sensitivity evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.