pub struct Packet { /* private fields */ }Expand description
Reviewable packet handed to staff or agents with deterministic gates already applied.
Implementations
Sourceimpl Packet
impl Packet
Sourcepub const fn workflow(&self) -> &'static str
pub const fn workflow(&self) -> &'static str
Returns the workflow evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn schema_version(&self) -> &'static str
pub const fn schema_version(&self) -> &'static str
Returns the schema version evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn context_packet_id(&self) -> &ContextPacketId
pub const fn context_packet_id(&self) -> &ContextPacketId
Returns the context packet id evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn correlation_id(&self) -> &CorrelationId
pub const fn correlation_id(&self) -> &CorrelationId
Returns the correlation id evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn location_id(&self) -> LocationId
pub const fn location_id(&self) -> LocationId
Returns the location id evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn operating_day(&self) -> Date
pub const fn operating_day(&self) -> Date
Returns the operating day evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn prepared_for(&self) -> HygienePersona
pub const fn prepared_for(&self) -> HygienePersona
Returns the prepared for evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub fn candidates(&self) -> &[Candidate]
pub fn candidates(&self) -> &[Candidate]
Returns the candidates evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub fn actions(&self) -> &[Action]
pub fn actions(&self) -> &[Action]
Returns the actions evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub fn safe_agent_actions(&self) -> &[SafeAgentAction]
pub fn safe_agent_actions(&self) -> &[SafeAgentAction]
Returns the safe agent actions evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub fn blocked_actions(&self) -> &[BlockedAction]
pub fn blocked_actions(&self) -> &[BlockedAction]
Returns the blocked actions evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn before_minutes(&self) -> AggregateLaborMinutes
pub const fn before_minutes(&self) -> AggregateLaborMinutes
Returns the before minutes evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn after_minutes(&self) -> AggregateLaborMinutes
pub const fn after_minutes(&self) -> AggregateLaborMinutes
Returns the after minutes evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn minutes_saved(&self) -> u16
pub const fn minutes_saved(&self) -> u16
Returns the minutes saved evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub fn all_actions_are_source_grounded(&self) -> bool
pub fn all_actions_are_source_grounded(&self) -> bool
Returns the all actions are source grounded evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub fn validate_draft(&self, draft: &DraftSubmission) -> DraftValidation
pub fn validate_draft(&self, draft: &DraftSubmission) -> DraftValidation
Returns the validate draft evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.