pub struct Request { /* private fields */ }Expand description
Input rules for building the workflow packet from source-grounded records.
Implementations
Sourceimpl Request
impl Request
Sourcepub fn builder() -> RequestBuilder
pub fn builder() -> RequestBuilder
Create an instance of Request using the builder syntax
Sourceimpl Request
impl Request
Sourcepub const fn location_id(&self) -> LocationId
pub const fn location_id(&self) -> LocationId
Returns the location id evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn operating_day(&self) -> Date
pub const fn operating_day(&self) -> Date
Returns the operating day evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn prepared_for(&self) -> HygienePersona
pub const fn prepared_for(&self) -> HygienePersona
Returns the prepared for evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub fn candidates(&self) -> &[Candidate]
pub fn candidates(&self) -> &[Candidate]
Returns the candidates evidence available to data-quality hygiene review while leaving provider, customer, payment, and schedule systems unchanged.