pub struct Action { /* private fields */ }Expand description
Action carried by the data-quality hygiene workflow; it finds duplicate, stale, or inconsistent records while blocking automatic provider-system mutation.
Implementations
Sourceimpl Action
impl Action
Sourcepub fn builder() -> ActionBuilder
pub fn builder() -> ActionBuilder
Create an instance of Action using the builder syntax
Sourceimpl Action
impl Action
Sourcepub const fn id(&self) -> &ActionId
pub const fn id(&self) -> &ActionId
Returns the id source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn kind(&self) -> ActionKind
pub const fn kind(&self) -> ActionKind
Returns the kind source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn priority(&self) -> ActionPriority
pub const fn priority(&self) -> ActionPriority
Returns the priority source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn owner_persona(&self) -> HygienePersona
pub const fn owner_persona(&self) -> HygienePersona
Returns the owner persona source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn removed_manual_work(&self) -> RemovedManualWork
pub const fn removed_manual_work(&self) -> RemovedManualWork
Returns the removed manual work source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn rationale(&self) -> &ActionRationale
pub const fn rationale(&self) -> &ActionRationale
Returns the rationale source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn source_record_refs(&self) -> &[RecordRef]
pub fn source_record_refs(&self) -> &[RecordRef]
Returns the source record refs source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn issue_refs(&self) -> &[IssueRef]
pub fn issue_refs(&self) -> &[IssueRef]
Returns the issue refs source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn required_review_gates(&self) -> &[ReviewGate]
pub fn required_review_gates(&self) -> &[ReviewGate]
Returns the required review gates source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn labor_impact(&self) -> &LaborImpactEstimate
pub const fn labor_impact(&self) -> &LaborImpactEstimate
Returns the labor impact source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn is_source_grounded(&self) -> bool
pub fn is_source_grounded(&self) -> bool
Reports whether the data-quality hygiene workflow satisfies the is source grounded safety condition.