pub struct Candidate { /* private fields */ }Expand description
Candidate carried by the data-quality hygiene workflow; it finds duplicate, stale, or inconsistent records while blocking automatic provider-system mutation.
Implementations
Sourceimpl Candidate
impl Candidate
Sourcepub fn builder() -> CandidateBuilder
pub fn builder() -> CandidateBuilder
Create an instance of Candidate using the builder syntax
Sourceimpl Candidate
impl Candidate
Sourcepub const fn id(&self) -> &IssueRef
pub const fn id(&self) -> &IssueRef
Returns the id source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn kind(&self) -> CandidateKind
pub const fn kind(&self) -> CandidateKind
Returns the kind source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn issue(&self) -> &Issue
pub const fn issue(&self) -> &Issue
Returns the issue source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn source_record_refs(&self) -> &[RecordRef]
pub fn source_record_refs(&self) -> &[RecordRef]
Returns the source record refs source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn source_freshness(&self) -> SourceFreshness
pub const fn source_freshness(&self) -> SourceFreshness
Returns the source freshness source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn sensitivity(&self) -> Sensitivity
pub const fn sensitivity(&self) -> Sensitivity
Returns the sensitivity source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.