pub struct Packet { /* private fields */ }Expand description
Reviewable packet handed to staff or agents with deterministic gates already applied.
Implementations
Sourceimpl Packet
impl Packet
Sourcepub const fn workflow(&self) -> &'static str
pub const fn workflow(&self) -> &'static str
Returns the workflow source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn schema_version(&self) -> &'static str
pub const fn schema_version(&self) -> &'static str
Returns the schema version source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn context_packet_id(&self) -> &ContextPacketId
pub const fn context_packet_id(&self) -> &ContextPacketId
Returns the context packet id source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn correlation_id(&self) -> &CorrelationId
pub const fn correlation_id(&self) -> &CorrelationId
Returns the correlation id source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn location_id(&self) -> LocationId
pub const fn location_id(&self) -> LocationId
Returns the location id source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn operating_day(&self) -> Date
pub const fn operating_day(&self) -> Date
Returns the operating day source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn prepared_for(&self) -> HygienePersona
pub const fn prepared_for(&self) -> HygienePersona
Returns the prepared for source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn candidates(&self) -> &[Candidate]
pub fn candidates(&self) -> &[Candidate]
Returns the candidates source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn actions(&self) -> &[Action]
pub fn actions(&self) -> &[Action]
Returns the actions source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn safe_agent_actions(&self) -> &[SafeAgentAction]
pub fn safe_agent_actions(&self) -> &[SafeAgentAction]
Returns the safe agent actions source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn blocked_actions(&self) -> &[BlockedAction]
pub fn blocked_actions(&self) -> &[BlockedAction]
Returns the blocked actions source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn before_minutes(&self) -> AggregateLaborMinutes
pub const fn before_minutes(&self) -> AggregateLaborMinutes
Returns the before minutes source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn after_minutes(&self) -> AggregateLaborMinutes
pub const fn after_minutes(&self) -> AggregateLaborMinutes
Returns the after minutes source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn minutes_saved(&self) -> u16
pub const fn minutes_saved(&self) -> u16
Returns the minutes saved source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn all_actions_are_source_grounded(&self) -> bool
pub fn all_actions_are_source_grounded(&self) -> bool
Returns the all actions are source grounded source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn validate_draft(&self, draft: &DraftSubmission) -> DraftValidation
pub fn validate_draft(&self, draft: &DraftSubmission) -> DraftValidation
Returns the validate draft source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.