pub struct Request { /* private fields */ }Expand description
Input contract for building the workflow packet from source-grounded records.
Implementations
Sourceimpl Request
impl Request
Sourcepub fn builder() -> RequestBuilder
pub fn builder() -> RequestBuilder
Create an instance of Request using the builder syntax
Sourceimpl Request
impl Request
Sourcepub const fn location_id(&self) -> LocationId
pub const fn location_id(&self) -> LocationId
Returns the location id source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn operating_day(&self) -> Date
pub const fn operating_day(&self) -> Date
Returns the operating day source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn prepared_for(&self) -> HygienePersona
pub const fn prepared_for(&self) -> HygienePersona
Returns the prepared for source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn candidates(&self) -> &[Candidate]
pub fn candidates(&self) -> &[Candidate]
Returns the candidates source evidence carried by this data-quality hygiene workflow artifact without changing provider, customer, payment, or schedule state.